@@ -6,7 +6,8 @@
 #' Click on the "Help" tab for instructions. Click the "Quit" button to exit the app and return
 #' the results from the \code{fitdist} command. Click "Download report" to generate a report
 #' of all the fitted distributions.
-#'   
+#' 
+#' @aliases elicitDirichlet condDirichlet  
 #' @return The parameters of the fitted Dirichlet distribution, which are 
 #' returned once the Quit button has been clicked. 
 #' @author Jeremy Oakley <j.oakley@@sheffield.ac.uk>
@@ -14,7 +15,7 @@
 #' 
 #' \dontrun{
 #' 
-#' elicit()
+#' elicitDirichlet()
 #' 
 #' }
 #' @import shiny
@@ -100,6 +101,7 @@ elicitDirichlet <- function(){
              includeHTML(system.file("shinyAppFiles", "DirichletHelp.html",
                                      package="SHELF")))
     
+    
   )
   
 ),
@@ -124,9 +126,18 @@ server = function(input, output) {
   
   
   output$DirichletPlot <- renderPlot({
+    if(all(theta$allValid() == TRUE)){
     fitDirichlet(theta$allFits(), categories = theta$categoryLabels(),
                  n.fitted = input$nFitted, silent = TRUE,
-                 fs = input$fs)
+                 fs = input$fs)}else{
+                   par(ps = 21)
+                   plot(1, 1, type = "n", xaxt = "n", yaxt = "n",
+                                          xlab = "", ylab = "", xlim = c(0, 1), ylim = c(0, 1)) 
+                   text(0, .8, "Dirichlet not fitted. On the Elicit marginals tab,
+check the smallest cumulative probability is < 0.4
+and the largest cumulative probability is > 0.6.",
+                        adj = c(0,1))
+                 }
   })
   
   output$categoryToFix <- renderUI({
@@ -137,6 +148,9 @@ server = function(input, output) {
   
   output$conditionalPlot <- renderPlot({
     req(input$categoryFixed)
+    
+    if(all(theta$allValid() == TRUE)){
+    
     d<- fittedDirichlet()
     selected <- which(input$categoryFixed == names(d))
     
@@ -197,12 +211,21 @@ server = function(input, output) {
                  aes(xintercept=input$obsValue),  colour="#00BFC4") +
       theme_grey(base_size = input$fs)
 
-    print(p1)
+    print(p1)}else{
+      par(ps = 21)
+      plot(1, 1, type = "n", xaxt = "n", yaxt = "n",
+           xlab = "", ylab = "", xlim = c(0, 1), ylim = c(0, 1)) 
+      text(0, .8, "Dirichlet not fitted. On the Elicit marginals tab,
+check the smallest cumulative probability is < 0.4
+and the largest cumulative probability is > 0.6.",
+           adj = c(0,1))
+      
+    }
     
   })
   
   output$feedback <- renderTable({
-    
+    req(all(theta$allValid() == TRUE))
     feedbackDirichlet(fittedDirichlet(),
                       quantiles = 
                         eval(parse(text = paste("c(", input$fq, ")")))
@@ -227,6 +250,8 @@ server = function(input, output) {
                             package="SHELF"),
                 tempReport, overwrite = TRUE)
       
+      # Check dirichlet has been fitted before continuing
+      req(all(theta$allValid() == TRUE))
       # Set up parameters to pass to Rmd document
       params <- list(allFits = theta$allFits(),
                      categories = theta$categoryLabels(),
